back-end performance 
====================

.. program-output:: python -m pyscreenshot.check.speedtest
    :prompt:


Test system versions:

.. program-output:: python -m pyscreenshot.check.versions 
    :prompt:
    